﻿using System;
using System.Collections.ObjectModel;
using System.Drawing;
using System.Web.Mvc;
using ThinkGeo.MapSuite;
using ThinkGeo.MapSuite.Drawing;
using ThinkGeo.MapSuite.Layers;
using ThinkGeo.MapSuite.Mvc;
using ThinkGeo.MapSuite.Shapes;
using ThinkGeo.MapSuite.Styles;

namespace PrintMap.Controllers
{
    public class HomeController : Controller
    {
        // GET: Home
        public ActionResult Index()
        {
            Map map = new Map("Map1",
               new System.Web.UI.WebControls.Unit(640, System.Web.UI.WebControls.UnitType.Pixel),
               new System.Web.UI.WebControls.Unit(640, System.Web.UI.WebControls.UnitType.Pixel));
            map.MapUnit = GeographyUnit.DecimalDegree;
            map.CurrentExtent = new RectangleShape(-134.01, 60.08, -56.60, 7.80);

            LayerOverlay layerOverlay = new LayerOverlay();
            layerOverlay.Layers.Add(new WorldStreetsAndImageryRasterLayer());
            map.CustomOverlays.Add(layerOverlay);

            return View(map);
        }

        [MapActionFilter]
        public void PrintMap(Map map, GeoCollection<object> args)
        {
            //Using PlatformGeoCanvas to draw layer and save image.
            double[] extentCell = Array.ConvertAll(args[0].ToString().Split(','), i => Convert.ToDouble(i));
            RectangleShape extent = new RectangleShape(extentCell[0], extentCell[3], extentCell[2], extentCell[1]);

            PlatformGeoCanvas canvas = new PlatformGeoCanvas();
            Bitmap bitmap = new Bitmap((int)map.Width.Value, (int)map.Height.Value);
            canvas.BeginDrawing(bitmap, extent, GeographyUnit.DecimalDegree);
            LayerOverlay layerOverlay = (LayerOverlay)map.CustomOverlays[0];
            foreach (Layer layer in layerOverlay.Layers)
            {
                layer.Open();
                layer.Draw(canvas, new Collection<SimpleCandidate>());
                layer.Close();
            }
            canvas.EndDrawing();

            bitmap.Save(@"C:\Temp\testMap.png");

            //Calling GetBitmap method to save map.
            //double[] extentCell = Array.ConvertAll(args[0].ToString().Split(','), i => Convert.ToDouble(i));
            //map.CurrentExtent = new RectangleShape(extentCell[0], extentCell[3], extentCell[2], extentCell[1]);
            //map.CurrentScale = Convert.ToDouble(args[1]);
            //Bitmap bitmap = map.GetBitmap();
            //bitmap.Save(@"C:\Temp\testMap.png");
        }
    }
}